# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.blueprint_file import BlueprintFile

class TestBlueprintFile(unittest.TestCase):
    """BlueprintFile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BlueprintFile:
        """Test BlueprintFile
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BlueprintFile`
        """
        model = BlueprintFile()
        if include_optional:
            return BlueprintFile(
                path = '',
                last_m = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                hash = '',
                meta = authentik_client.models.metadata.Metadata(
                    name = '', 
                    labels = {
                        'key' : null
                        }, )
            )
        else:
            return BlueprintFile(
                path = '',
                last_m = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                hash = '',
                meta = authentik_client.models.metadata.Metadata(
                    name = '', 
                    labels = {
                        'key' : null
                        }, ),
        )
        """

    def testBlueprintFile(self):
        """Test BlueprintFile"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
